News-Scraper
===

Create a digest of news stories based on provided URLs.

## Installation

1. Download and install [Python 3](https://www.python.org/downloads/)
2. In a terminal, run `pip3 install news_scraper`

## Usage

In a terminal, run `news-scraper`

Output will appear in `output.html`, which will be automatically opened.

### Supported news sites

NY Daily News, NY Times

### Tweaks

Edit the `bodyLines` variable near the top of `news-scraper.py` to control the number of sentences in the article body.

## Feedback

[marc@khouri.ca](mailto:marc@khouri.ca)

[Issues and feature requests](https://github.com/mnkhouri/news-scraper/issues)




